@@ -4,10 +4,16 @@ from django import template
 from django.utils.safestring import mark_safe
 
 try:
-    from django.contrib.staticfiles.templatetags.staticfiles import static
+    from django.templatetags.static import static
+except ImportError:
+    try:
+        from django.contrib.staticfiles.templatetags.staticfiles import static
+    except ImportError:
+        from staticfiles.templatetags.staticfiles import static
+
+try:
     from django.contrib.staticfiles.storage import staticfiles_storage
 except ImportError:
-    from staticfiles.templatetags.staticfiles import static
     from staticfiles.storage import staticfiles_storage
 
 from statici18n.conf import settings
@@ -42,4 +48,4 @@ def inlinei18n(locale):
     Behind the scenes, this is a thin wrapper around staticfiles's configred
     storage
     """
-    return mark_safe(staticfiles_storage.open(get_path(locale)).read())
+    return mark_safe(staticfiles_storage.open(get_path(locale)).read().decode())
